@@ -3,7 +3,7 @@
 #' @description 
 #' `r antaresEditObject:::badge_api_no()`
 #' 
-#' Save an Antares Study or only inputs in a \code{.tar.gz} file
+#' Save an Antares Study or only inputs in a \code{.tar.gz} or \code{.zip} file
 #'
 #' @param backupfile Name of the backup, without extension. If missing, 
 #' either the name of the study or 'input' according argument \code{what}.
@@ -12,6 +12,7 @@
 #' @param opts
 #'   List of simulation parameters returned by the function
 #'   \code{antaresRead::setSimulationPath}
+#' @param extension Defaut is {.zip}.
 #'
 #' @return The path of the backup
 #' @export
@@ -23,16 +24,17 @@
 #' \dontrun{
 #' backupStudy()
 #' }
-backupStudy <- function(backupfile, what = c("input", "study"), opts = antaresRead::simOptions()) {
-  
-  what <- match.arg(arg = what)
+backupStudy <- function(backupfile, what = "study", 
+                        opts = antaresRead::simOptions(), extension = ".zip") {
   
+  assertthat::assert_that(what %in% c("study", "input"))  
   assertthat::assert_that(inherits(opts, "simOptions"))
+  assertthat::assert_that(extension %in% c(".tar.gz", ".zip"))
   api_not_implemented(opts)
   assertthat::assert_that(!is.null(opts$studyPath) && dir.exists(opts$studyPath))
   
   if (missing(backupfile))
-    backupfile <- ifelse(what == "study", opts$studyName, what)
+    backupfile <- ifelse(what == "study", opts$studyPath, what)
   
   # backupfile <- file.path(dirname(opts$studyPath), paste0(backupfile, ".tar.gz"))
   
@@ -46,26 +48,20 @@ backupStudy <- function(backupfile, what = c("input", "study"), opts = antaresRe
   }
   setwd(zip_dir)
   
+  if (file.exists(paste0(backupfile, extension))) stop("Backup already exists in this folder.")
   tryCatch(
-    utils::tar(
-      tarfile = paste0(backupfile, ".tar.gz"),
-      files = zip_files,
-      compression = "gzip"
-    )
+    if (extension == ".tar.gz")
+      utils::tar(tarfile = paste0(backupfile, ".tar.gz"), files = zip_files, compression = "gzip")
+    else utils::zip(zipfile = paste0(backupfile, ".zip"), files = zip_files)
     , error = function(e) {
-      stop("Could not write ", shQuote(paste0(backupfile, ".tar.gz")), " [", e$message, "]")
+      stop("Could not write ", shQuote(paste0(backupfile, extension)), " [", e$message, "]")
     }
     , finally = {
       setwd(curr_wd)
   })
   
-  res <- file.path(zip_dir, paste0(backupfile, ".tar.gz"))
+  return (paste0(backupfile, extension))
   
-  if( !file.exists(res) ){
-    stop("Failed to create backup", call. = FALSE)
-  }
-  
-  res
 }
 # backupSimulation <- function(backupfile, opts = antaresRead::simOptions()) {
 #   
