@@ -13,6 +13,7 @@
 #' @param ... Parameters to write in the Ini file. Careful!
 #'  Some parameters must be set as `integers` to avoid warnings in Antares, for example, 
 #'  to set `unitcount`, you'll have to use `unitcount = 1L`.
+#' @param list_pollutants `list` named with specific pollutants (only for Antares version >= 860)  
 #' @param time_series the "ready-made" 8760-hour time-series available for simulation purposes.
 #' @param prepro_data Pre-process data, a `data.frame` or `matrix`, 
 #'  default is a matrix with 365 rows and 6 columns.
@@ -27,12 +28,23 @@
 #' 
 #' @export
 #' 
-#' @name create-cluster
+#' @name createCluster
 #' 
 #' @importFrom antaresRead simOptions
 #' @importFrom stats setNames
 #' @importFrom utils read.table write.table
 #' @importFrom data.table setcolorder year yday month setnames
+#' 
+#' @note 
+#' Parameter `list_pollutants` is only available for Antares studies >= v8.6.0.  
+#' 
+#' You must provide named `list` (numerical values or NULL ) :    
+#' 
+#' `list(
+#' "nh3"= 0.25, "nox"= 0.45, "pm2_5"= 0.25,  
+#' "pm5"= 0.25, "pm10"= 0.25, "nmvoc"= 0.25, "so2"= 0.25, 
+#' "op1"= 0.25, "op2"= 0.25, "op3"= 0.25,  
+#' "op4"= 0.25, "op5"= NULL, "co2"= NULL)`
 #'
 #' @examples
 #' \dontrun{
@@ -144,12 +156,40 @@ createCluster <- function(area,
                           cluster_name, 
                           group = "Other",
                           ...,
+                          list_pollutants = list_pollutants_values(),
                           time_series = NULL,
                           prepro_data = NULL,
                           prepro_modulation = NULL,
                           add_prefix = TRUE, 
                           overwrite = FALSE,
                           opts = antaresRead::simOptions()) {
+  # check study parameters
+  assertthat::assert_that(inherits(opts, "simOptions"))
+  
+  # static name of list parameters of pulluants
+  name_list_param_poll <- names(list_pollutants_values())
+  
+  # check v860
+    # check list pulluants parameters
+  if(opts$antaresVersion >= 860){
+    if(!is.null(list_pollutants) & !assert_that(inherits(list_pollutants, "list")))
+      stop("Parameter 'list_pollutants' must be a 'list'")
+    
+    if(!all(names(list_pollutants) %in% name_list_param_poll))
+      stop(append("Parameter 'list_pollutants' must be named with the following elements: ", 
+                  paste0(name_list_param_poll, collapse= ", ")))
+    
+    # check if all elements are NULL => replace by NULL 
+      # API (only) can't create with NULL values
+    all_null <- lapply(list_pollutants, is.null)
+    all_null <- all(unlist(all_null))
+    
+    if(all_null)
+      list_pollutants <- NULL
+  }
+    
+  
+  # statics groups
   thermal_group <- c("Gas",
                      "Hard coal",
                      "Lignite",
@@ -160,16 +200,19 @@ createCluster <- function(area,
                      "Other 2",
                      "Other 3",
                      "Other 4")
+  
   if (!is.null(group) && !tolower(group) %in% tolower(thermal_group))
     warning(
       "Group: '", group, "' is not a valid name recognized by Antares,",
       " you should be using one of: ", paste(thermal_group, collapse = ", ")
     )
+  
   .createCluster(
     area = area, 
     cluster_name = cluster_name, 
     group = group,
     ...,
+    list_pollutants = list_pollutants,
     time_series = time_series,
     prepro_data = prepro_data,
     prepro_modulation = prepro_modulation,
@@ -182,7 +225,7 @@ createCluster <- function(area,
 
 #' @export
 #' 
-#' @rdname create-cluster
+#' @rdname createCluster
 createClusterRES <- function(area, 
                              cluster_name, 
                              group = "Other RES 1",
@@ -227,6 +270,7 @@ createClusterRES <- function(area,
 .createCluster <- function(area, 
                            cluster_name, 
                            ...,
+                           list_pollutants = NULL,
                            time_series = NULL,
                            prepro_data = NULL,
                            prepro_modulation = NULL,
@@ -258,6 +302,10 @@ createClusterRES <- function(area,
     cluster_name <- paste(area, cluster_name, sep = "_")
   params_cluster$name <- cluster_name
   
+  # v860 pollutants
+  if(opts$antaresVersion >= 860)
+    params_cluster <- append(params_cluster, list_pollutants)
+  
   # API block
   if (is_api_study(opts)) {
     
@@ -415,3 +463,27 @@ createClusterRES <- function(area,
 # )
 
 
+#' Output pollutants list for thermal clusters
+#'
+#' @param multi_values put values to init list values, default as `NULL`
+#'
+#' @return a named list
+#' @export
+#'
+#' @examples
+#' list_pollutants_values()
+list_pollutants_values <- function(multi_values = NULL) {
+  list("nh3"= multi_values, 
+       "nox"= multi_values, 
+       "pm2_5"= multi_values, 
+       "pm5"= multi_values, 
+       "pm10"= multi_values, 
+       "nmvoc"= multi_values, 
+       "so2"= multi_values, 
+       "op1"= multi_values, 
+       "op2"= multi_values, 
+       "op3"= multi_values, 
+       "op4"= multi_values, 
+       "op5"= multi_values, 
+       "co2"= multi_values)
+}
